@@ -28,7 +28,7 @@ See: http://en.wikipedia.org/wiki/ANSI_escape_code
 #  Based on colorama
 #  https://github.com/tartley/colorama
 #  Copyright Jonathan Hartley 2013
-#  Distrubuted under the BSD 3-Clause license.
+#  Distributed under the BSD 3-Clause license.
 #  |  Redistribution and use in source and binary forms, with or without
 #  |  modification, are permitted provided that the following conditions are met:
 #  |
@@ -56,10 +56,16 @@ See: http://en.wikipedia.org/wiki/ANSI_escape_code
 #
 #  Includes modifications to colorama made by Bram Geelen in
 #  https://github.com/tartley/colorama/pull/141/files
+#
+#  _ansi_re and strip_ansi based on https://github.com/pallets/click
+#  Copyright 2014 Pallets
+#  Distributed under the BSD 3-Clause license.
+#
 
 # stdlib
+import re
 from abc import ABC
-from typing import List
+from typing import List, Pattern
 
 # 3rd party
 from colorama import init  # type: ignore
@@ -83,13 +89,14 @@ __all__ = [
 		"Back",
 		"Style",
 		"Cursor",
+		"strip_ansi",
 		]
 
 init()
 
 CSI: Final[str] = "\033["
 OSC: Final[str] = "\033]"
-BEL: Final[str] = '\a'
+BEL: Final[str] = "\a"
 
 fore_stack: List[str] = []
 back_stack: List[str] = []
@@ -101,7 +108,7 @@ def code_to_chars(code) -> str:
 
 
 def set_title(title: str) -> str:
-	return OSC + '2;' + title + BEL
+	return OSC + "2;" + title + BEL
 
 
 def clear_screen(mode: int = 2) -> str:
@@ -112,18 +119,35 @@ def clear_line(mode: int = 2) -> str:
 	return CSI + str(mode) + 'K'
 
 
-class Colour(str):
+_ansi_re: Pattern[str] = re.compile(r"\033\[[;?0-9]*[a-zA-Z]")
+
+
+def strip_ansi(value: str) -> str:
 	"""
+	Strip ANSI colour codes from the given string to return a plaintext output.
+
+	:param value:
+
+	:rtype:
+
+	.. versionadded:: 1.1.0
+	"""
+
+	return _ansi_re.sub("", value)
+
+
+class Colour(str):
+	r"""
 	An ANSI escape sequence representing a colour.
 
 	The colour can be used as a context manager, a string, or a function.
 
 	:param style: Escape sequence representing the style.
-	:type style: str
+	:type style: :class:`str`
 	:param stack: The stack to place the escape sequence on.
-	:type stack: str
-	:param reset: The escape requence the reset the style.
-	:type reset: str
+	:type stack: :class:`~typing.List`\[:class:`str`\]
+	:param reset: The escape sequence to reset the style.
+	:type reset: :class:`str`
 	"""
 
 	style: str
@@ -148,6 +172,10 @@ class Colour(str):
 			print(self.stack[-1], end='')
 
 	def __call__(self, text) -> str:
+		"""
+		Returns the given text in this colour.
+		"""
+
 		return f"{self}{text}{self.reset}"
 
 
@@ -179,9 +207,6 @@ class AnsiCursor:
 		"""
 
 		:param n:
-		:type n: int
-
-		:return:
 		"""
 
 		return f"{CSI}{str(n)}A"
@@ -190,9 +215,6 @@ class AnsiCursor:
 		"""
 
 		:param n:
-		:type n: int
-
-		:return:
 		"""
 
 		return f"{CSI}{str(n)}B"
@@ -201,9 +223,6 @@ class AnsiCursor:
 		"""
 
 		:param n:
-		:type n: int
-
-		:return:
 		"""
 
 		return f"{CSI}{str(n)}C"
@@ -212,9 +231,6 @@ class AnsiCursor:
 		"""
 
 		:param n:
-		:type n: int
-
-		:return:
 		"""
 
 		return f"{CSI}{str(n)}D"
@@ -223,11 +239,7 @@ class AnsiCursor:
 		"""
 
 		:param x:
-		:type x: int
 		:param y:
-		:type y: int
-
-		:return:
 		"""
 
 		return f"{CSI}{str(y)};{str(x)}H"
